
const fs = require('fs');
const path = require('path');
const express = require('../../../../../../Projects/node/node_modules/express');
const puppeteer = require('../../../../../../Projects/node/node_modules/puppeteer');

const srv = express();
srv.use(express.static(path.join(__dirname, 'src')));
srv.listen(8727, () => console.log(`HTTP is listening`));

async function main() {
    const config = require('./config.json');
    const mtimes = require('./mtimes.json');
    const changedFiles = [];
    fs.readdirSync('./src').forEach(file => {
        const stats = fs.statSync(`./src/${file}`);
        if (stats.mtimeMs !== mtimes[file]) {
            changedFiles.push(file);
            mtimes[file] = stats.mtimeMs;
            console.log(`${file} has changed!`);
        }
    });
    const browser = await puppeteer.launch();
    const images = Object.keys(config.images).reverse();
    const imageNames = [];
    if (config.limit_to_url) console.log(`Limiting to URLs:`, config.limit_to_url);
    images.forEach(image => {
        if (config.limit_to_url && !config.limit_to_url.includes(config.images[image].url)) return;
        imageNames.push(image);
    });
    let batches = [];
    let batch = [];
    imageNames.forEach(name => {
        batch.push(name);
        if (batch.length >= 4) {
            batches.push(batch);
            batch = [];
        }
    });
    batches.push(batch);
    let i = 0;
    batches.forEach(async(batch) => {
        for (const name of batch) {
            const details = config.images[name];
            const page = await browser.newPage();
            let size = details.size;
            if (details.useSize) size = config.images[details.useSize].size;
            await page.setViewport({ width: size[0], height: size[1] });
            let params = details.params;
            if (details.useParams) params = config.images[details.useParams].params;
            const queryString = new URLSearchParams(params).toString();
            await page.goto(`http://localhost:8727/${details.url}?${queryString}`);
            await page.waitForNetworkIdle();
            const imageName = `${name}.png`;
            await page.screenshot({
                path: `./output/${imageName}`,
                type: 'png',
                omitBackground: true
            });
            await page.close();
            fs.copyFileSync(`./output/${imageName}`, `../${imageName}`);
            console.log(`Saved ${name}`);
            i++;
        }
    });
    setInterval(() => {
        console.log(i, 'of', imageNames.length);
        if (i == imageNames.length) {
            browser.close();
            fs.writeFileSync('./mtimes.json', JSON.stringify(mtimes, null, 4));
            process.exit();
        }
    }, 1000);
}
main();