
process.chdir(__dirname);

const fs = require('fs');
const path = require('path');
const cp = require('child_process');
const express = require('../../../../../../Projects/node/node_modules/express');
const puppeteer = require('../../../../../../Projects/node/node_modules/puppeteer');
const chokidar = require('../../../../../../Projects/node/node_modules/chokidar');

const srv = express();
srv.use(express.static(path.join(__dirname, '../')));
srv.listen(8728, () => console.log(`HTTP is listening`));

const _browser = puppeteer.launch();

async function go(filePath) {
    const file = path.basename(filePath);
    const fileNoExt = file.split('.')[0];
    const isGreen = file.match(/(ranking-panel|selection-mode)/) ? true : false;
    console.log(`[${file}] Waiting for puppeteer...`);
    const browser = await _browser;
    const page = await browser.newPage();
    console.log(`[${file}] Converting to PNG...`);
    await page.goto(`http://localhost:8728/puppet-builder/src/image.html?src=/${file}`);
    await page.waitForNetworkIdle();
    const size = require('./svgSizes.json')[fileNoExt];
    if (!size) {
        console.log(`[${file}] No size is defined!`);
        return;
    }
    await page.setViewport({ width: size[0], height: size[1] });
    const imageName = `../${fileNoExt}.png`;
    const imageNameTemp = (isGreen) ? imageName.replace('.png', '-green.png') : imageName;
    await page.screenshot({
        path: imageNameTemp,
        type: 'png',
        omitBackground: true
    });
    await page.close();
    if (isGreen) {
        console.log(`[${file}] Creating transparency...`);
        cp.spawnSync(`magick convert "${imageNameTemp}" -fuzz 35% -transparent "#00ff00" "${imageName}"`, { shell: true });
        //fs.unlinkSync(imageNameTemp);
    }
    console.log(`[${file}] Saved ${imageName}!`);
}

const watcher = chokidar.watch('../*.svg', { ignoreInitial: true, awaitWriteFinish: true });
watcher.on('add', go);
watcher.on('change', go);
console.log(`Watching .svg files for changes...`);